%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                 Plotting responses with PD control                  %%%
%%%                 for a constant reference trajectory.                %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Saving values sent to workspace in vectors easier to handle 
t = states.time;

q1 = states.signals.values(1,:);
Dq1 = states.signals.values(2,:);
q2 = states.signals.values(3,:);
Dq2 = states.signals.values(4,:);
q3 = states.signals.values(5,:);
Dq3 = states.signals.values(6,:);

u1 = torque.signals.values(:,1);
u2 = torque.signals.values(:,2);
u3 = torque.signals.values(:,3);


%Plotting the response of the joint variables
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,q1,'k',t,q2,'b',t,q3,'g','LineWidth',2);
grid on;
axis([0 4 -0.6 1]);
xlabel('Time [s]')
ylabel('Radians')
title('Response of q','FontSize',12)
legend('q_1','q_2','q_3','Location','NorthEast')


%Plotting the response of the derivate joint variables
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,Dq1,'k',t,Dq2,'b',t,Dq3,'g','LineWidth',2);
grid on;
xlabel('Time [s]')
ylabel('Radians')
title('Response of qdot','FontSize',12)
legend('dq_1','dq_2','dq_3','Location','NorthEast')


%Plotting the input torques
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,u1,'k',t,u2,'b',t,u3,'g','LineWidth',2);
grid on;
axis([0 4 -100 100]);
xlabel('Time [s]')
ylabel('Torque [Nm]')
title('Input torque','FontSize',12)
legend('\tau_1','\tau_2','\tau_3','Location','NorthEast')

