function IRB140(block)
setup(block);

function setup(block)
    %% Register number of input and output ports
    block.NumInputPorts  = 2;
    block.NumOutputPorts = 1;

    %% Setup functional port properties to dynamically inherited.
    block.SetPreCompInpPortInfoToDynamic;
    block.SetPreCompOutPortInfoToDynamic;


    %% Hard-code certain port properties
    block.InputPort(1).Dimensions  = [6 1];
    block.InputPort(2).Dimensions  = [3 1];
    block.InputPort(1).DirectFeedthrough = false;
    block.InputPort(2).DirectFeedthrough = false;
    block.OutputPort(1).Dimensions  = [6 1];
  
    %% Register a single dialog parameter
    block.NumDialogPrms = 0;

    %% Set block sample time
    block.SampleTimes = [-1 0];
  
    %% Decide Accelerator (Call back to m-file or use TLC)  
    block.SetAccelRunOnTLC(false);
    
    %% Register a callback method for block  
    block.RegBlockMethod('InitializeConditions', @InitializeConditions);
    block.RegBlockMethod('Outputs', @Outputs);

    
function InitializeConditions(block)
    block.InputPort(1).Data(1) = 0;
    block.InputPort(1).Data(2) = 0;
    block.InputPort(1).Data(3) = 0;
    block.InputPort(1).Data(4) = 0;
    block.InputPort(1).Data(5) = 0;
    block.InputPort(1).Data(6) = 0;
    
function Outputs(block)
    %% Input definitions  
    u1 = block.InputPort(2).Data(1);
    u2 = block.InputPort(2).Data(2);
    u3 = block.InputPort(2).Data(3);

    
    q1  = block.InputPort(1).Data(1);
    Dq1 = block.InputPort(1).Data(2);
    q2  = block.InputPort(1).Data(3);
    Dq2 = block.InputPort(1).Data(4);
    q3  = block.InputPort(1).Data(5);
    Dq3 = block.InputPort(1).Data(6);

    %% Defining the Matrix-elements from Maple calculations
    
    %% Mass values found from SolidWorks calculations
    m1 = 34.655;
    m2 = 15.994;
    m3 = 20.862;

    %% Inertia tensor matrices found by SolidWorks calculations
    i11x = 0.51205253974; i11y = -0.385971e-2;  i11z = 0.051305;
    i12x = 0.00136134;    i12y = 0.46407468859; i13z = 0.0703356;
    i13x = 0.051305;      i13y = -0.627205e-1;  i13z = 0.55411384358;

    i21x = 0.0948179;     i21y = -0.385971e-2;  i21z = 0.037932;
    i22x = -0.385971e-2;  i22y = 0.32860416324; i22z = -0.108897e-2;
    i23x = 0.037932;      i23y = -0.108897e-2;  i23z = 0.27746300488;

    i31x = 0.50006091595; i31y = -0.186325e-2;  i31z = 0.000934876;
    i32x = -0.186325e-2;  i32y = 0.0751527;     i32z = -0.152041e-1;
    i33x = 0.000934876;   i33y = -0.152041e-1;  i33z = 0.51542475434;

    %% Vectors from frame i-1 to mass center of link i
    r0c1x = 0.08903; r0c1y = -0.2789e-1; r0c1z = 0.04312;
    r1c2x = 0.19829; r1c2y = -0.9243e-1; r1c2z = 0.00973;
    r2c3x = 0.07996; r2c3y = 0.00456;    r2c3z = 0.00586;

    %% Inertia Matrix Estimate       
    m11 = 0.5000000000e0 * i32y + 0.5000000000e0 * i31x + 0.5000000000e0 * i22y + 0.5000000000e0 * i21x + m3 * 0.696999999999999981e-1 + 0.1e1 * i12y + m2 * 0.490000000000000071e-2 + 0.1000000000e1 * r1c2y * m2 * r1c2x * sin((2 * q2)) - 0.1000000000e1 * m3 * r2c3y * r2c3x * sin((2 * q3 + 2 * q2)) + 0.5000000000e0 * m2 * r1c2y ^ 2 + 0.5000000000e0 * m2 * r1c2x ^ 2 + 0.5000000000e0 * m3 * r2c3x ^ 2 * cos((2 * q3 + 2 * q2)) - 0.5000000000e0 * m2 * r1c2x ^ 2 * cos((2 * q2)) + m3 * r2c3y * sin((q3 + q2)) * (-0.140000000000000013e0) + m2 * r1c2y * cos(q2) * 0.140000000000000013e0 + m3 * r2c3x * cos((q3 + q2)) * 0.140000000000000013e0 + m2 * r1c2x * sin(q2) * 0.140000000000000013e0 + 0.5000000000e0 * m2 * r1c2y ^ 2 * cos((2 * q2)) + m3 * r2c3y * cos((q3 + 2 * q2)) * 0.359999999999999987e0 - 0.5000000000e0 * m3 * r2c3y ^ 2 * cos((2 * q3 + 2 * q2)) + m3 * r2c3x * sin((q3 + 2 * q2)) * 0.359999999999999987e0 + 0.5000000000e0 * m3 * r2c3y ^ 2 + 0.5000000000e0 * m3 * r2c3x ^ 2 + r2c3y * m3 * cos(q3) * (-0.359999999999999987e0) + r2c3x * m3 * sin(q3) * (-0.359999999999999987e0) + 0.1000000000e1 * m2 * r1c2z ^ 2 + 0.1e1 * m1 * r0c1z ^ 2 + 0.1e1 * m1 * r0c1x ^ 2 + 0.1000000000e1 * m3 * r2c3z ^ 2 + m3 * sin(q2) * 0.504000000000000004e-1 + m3 * cos((2 * q2)) * (-0.647999999999999965e-1) - 0.5000000000e0 * i22y * cos((2 * q2)) - 0.5000000000e0 * i21y * sin((2 * q2)) + 0.5000000000e0 * i21x * cos((2 * q2)) - 0.5000000000e0 * i31x * cos((2 * q3 + 2 * q2)) + 0.5000000000e0 * i31y * sin((2 * q3 + 2 * q2)) + 0.5000000000e0 * i32x * sin((2 * q3 + 2 * q2)) + 0.5000000000e0 * i32y * cos((2 * q3 + 2 * q2)) - 0.5000000000e0 * i22x * sin((2 * q2));
    m12 = -0.1000000000e1 * i31z * sin(q3 + q2) - 0.1000000000e1 * i32z * cos(q3 + q2) - 0.1000000000e1 * r1c2x * m2 * r1c2z * cos(q2) + 0.1000000000e1 * r2c3x * m3 * r2c3z * sin(q3 + q2) - 0.1000000000e1 * sin(q2) * i22z + 0.1000000000e1 * r1c2y * m2 * r1c2z * sin(q2) + 0.1000000000e1 * cos(q2) * i21z + 0.1000000000e1 * r2c3y * m3 * r2c3z * cos(q3 + q2) - 0.3600000000e0 * m3 * r2c3z * cos(q2);
    m13 = 0.1000000000e1 * r2c3x * m3 * r2c3z * sin(q3 + q2) + 0.1000000000e1 * r2c3y * m3 * r2c3z * cos(q3 + q2) - 0.1000000000e1 * i31z * sin(q3 + q2) - 0.1000000000e1 * i32z * cos(q3 + q2);
    m21 = 0.1000000000e1 * r1c2y * m2 * r1c2z * sin(q2) + 0.1000000000e1 * r2c3y * m3 * r2c3z * cos(q3 + q2) - 0.1000000000e1 * i23y * sin(q2) + 0.1000000000e1 * r2c3x * m3 * r2c3z * sin(q3 + q2) - 0.1000000000e1 * r1c2x * m2 * r1c2z * cos(q2) + 0.1000000000e1 * i23x * cos(q2) + m3 * r2c3z * cos(q2) * (-0.359999999999999987e0) - 0.1000000000e1 * i33x * sin(q3 + q2) - 0.1000000000e1 * i33y * cos(q3 + q2);
    m22 = r2c3y * m3 * cos(q3) * (-0.719999999999999973e0) + r2c3x * m3 * sin(q3) * (-0.719999999999999973e0) + 0.1000000000e1 * m3 * r2c3y ^ 2 + 0.1000000000e1 * m2 * r1c2y ^ 2 + 0.1000000000e1 * m2 * r1c2x ^ 2 + 0.1000000000e1 * i23z + m3 * 0.129599999999999993e0 + 0.1000000000e1 * m3 * r2c3x ^ 2 + 0.1000000000e1 * i33z;
    m23 = 0.1000000000e1 * i33z + 0.1000000000e1 * m3 * r2c3x ^ 2 + r2c3y * m3 * cos(q3) * (-0.359999999999999987e0) + r2c3x * m3 * sin(q3) * (-0.359999999999999987e0) + 0.1000000000e1 * m3 * r2c3y ^ 2;
    m31 = 0.1000000000e1 * r2c3y * m3 * r2c3z * cos(q3 + q2) + 0.1000000000e1 * r2c3x * m3 * r2c3z * sin(q3 + q2) - 0.1000000000e1 * i33x * sin(q3 + q2) - 0.1000000000e1 * i33y * cos(q3 + q2);
    m32 = 0.1000000000e1 * i33z + 0.1000000000e1 * m3 * r2c3y ^ 2 - 0.3600000000e0 * r2c3y * m3 * cos(q3) + 0.1000000000e1 * m3 * r2c3x ^ 2 - 0.3600000000e0 * r2c3x * m3 * sin(q3);
    m33 = 0.1000000000e1 * i33z + 0.1000000000e1 * m3 * r2c3y ^ 2 + 0.1000000000e1 * m3 * r2c3x ^ 2;

    %% Gravity Vector Estimate
    g = 9.81;
    g1 = 0;
    g2 = 0.1000000000e1 * r2c3y * m3 * sin(q3 + q2) * g - 0.1000000000e1 * r1c2y * m2 * cos(q2) * g - 0.1000000000e1 * r1c2x * m2 * sin(q2) * g - 0.1000000000e1 * r2c3x * m3 * cos(q3 + q2) * g + m3 * g * sin(q2) * (-0.359999999999999987e0);
    g3 = -0.1000000000e1 * r2c3x * m3 * cos(q3 + q2) * g + 0.1000000000e1 * r2c3y * m3 * sin(q3 + q2) * g;

    %% Coriolis & Centrifugal matrix Estimate
    c11 = sin(q2) * m3 * Dq1 * r2c3z * (-0.277555756156289135e-16) + ((0.1000000000e1 * m3 * r2c3y ^ 2 * sin((2 * q3) + 0.2e1 * q2) + r1c2x * m2 * cos(q2) * 0.140000000000000013e0 + r2c3x * m3 * sin(q3 + q2) * (-0.140000000000000013e0) + r2c3x * m3 * cos(q3) * (-0.555111512312578270e-16) + r2c3x * m3 * cos(q3 + 0.2e1 * q2) * 0.719999999999999973e0 - 0.1000000000e1 * i21x * sin(0.2e1 * q2) - 0.1000000000e1 * m2 * r1c2y ^ 2 * sin(0.2e1 * q2) + 0.1000000000e1 * m2 * r1c2x ^ 2 * sin(0.2e1 * q2) - 0.1000000000e1 * m3 * r2c3x ^ 2 * sin((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * cos(q3 + q2) * (-0.140000000000000013e0) - 0.1000000000e1 * i22x * cos(0.2e1 * q2) - 0.1000000000e1 * i32y * sin((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * sin(q3) * 0.555111512312578270e-16 + r1c2y * m2 * sin(q2) * (-0.140000000000000013e0) + 0.1000000000e1 * i32x * cos((2 * q3) + 0.2e1 * q2) + 0.1000000000e1 * i31y * cos((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * sin(q3 + 0.2e1 * q2) * (-0.719999999999999973e0) + m3 * cos(q2) * 0.504000000000000004e-1 + m3 * sin(0.2e1 * q2) * 0.129599999999999993e0 + 0.1000000000e1 * i22y * sin(0.2e1 * q2) + 0.1000000000e1 * i31x * sin((2 * q3) + 0.2e1 * q2) + 0.2000000000e1 * r1c2y * m2 * r1c2x * cos(0.2e1 * q2) - 0.1000000000e1 * i21y * cos(0.2e1 * q2) - 0.2000000000e1 * r2c3y * m3 * r2c3x * cos((2 * q3) + 0.2e1 * q2)) * Dq2 + (-0.1000000000e1 * i32y * sin((2 * q3) + 0.2e1 * q2) - 0.1000000000e1 * m3 * r2c3x ^ 2 * sin((2 * q3) + 0.2e1 * q2) + r2c3x * m3 * cos(q3 + 0.2e1 * q2) * 0.359999999999999987e0 + 0.1000000000e1 * m3 * r2c3y ^ 2 * sin((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * sin(q3 + 0.2e1 * q2) * (-0.359999999999999987e0) - 0.2000000000e1 * r2c3y * m3 * r2c3x * cos((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * cos(q3 + q2) * (-0.140000000000000013e0) + r2c3x * m3 * cos(q3) * (-0.359999999999999987e0) + r2c3x * m3 * sin(q3 + q2) * (-0.140000000000000013e0) + 0.1000000000e1 * i31x * sin((2 * q3) + 0.2e1 * q2) + r2c3y * m3 * sin(q3) * 0.359999999999999987e0 + 0.1000000000e1 * i31y * cos((2 * q3) + 0.2e1 * q2) + 0.1000000000e1 * i32x * cos((2 * q3) + 0.2e1 * q2)) * Dq3);
    c12 = (-0.1000000000e1 * cos(q2) * i22z - 0.1000000000e1 * cos(q3 + q2) * i31z - 0.1000000000e1 * sin(q2) * i21z + 0.1000000000e1 * r2c3z * m3 * r2c3x * cos(q3 + q2) + 0.1000000000e1 * sin(q3 + q2) * i32z - 0.1000000000e1 * r2c3z * m3 * r2c3y * sin(q3 + q2) + 0.1000000000e1 * sin(q2) * r1c2z * m2 * r1c2x + 0.1000000000e1 * cos(q2) * r1c2z * m2 * r1c2y + 0.3600000000e0 * sin(q2) * m3 * r2c3z) * Dq2 + (-0.2000000000e1 * cos(q3 + q2) * i31z - 0.2000000000e1 * r2c3z * m3 * r2c3y * sin(q3 + q2) + 0.2000000000e1 * sin(q3 + q2) * i32z + 0.2000000000e1 * r2c3z * m3 * r2c3x * cos(q3 + q2)) * Dq3;
    c13 = (-0.1000000000e1 * cos(q3 + q2) * i31z - 0.1000000000e1 * r2c3z * m3 * r2c3y * sin(q3 + q2) + 0.1000000000e1 * sin(q3 + q2) * i32z + 0.1000000000e1 * r2c3z * m3 * r2c3x * cos(q3 + q2)) * Dq3 ^ 2;
    c21 = (-0.5000000000e0 * m2 * r1c2x ^ 2 * sin((2 * q2)) - 0.7000000000e-1 * r1c2x * m2 * cos(q2) + 0.5000000000e0 * m2 * r1c2y ^ 2 * sin((2 * q2)) + 0.7000000000e-1 * r1c2y * m2 * sin(q2) + 0.5000000000e0 * i32x - 0.5000000000e0 * i31y + 0.5000000000e0 * i22x - 0.5000000000e0 * i21y + 0.5000000000e0 * i21x * sin((2 * q2)) + 0.5000000000e0 * i21y * cos((2 * q2)) + 0.5000000000e0 * i22x * cos((2 * q2)) - 0.5000000000e0 * i22y * sin((2 * q2)) + m3 * sin((2 * q2)) * (-0.647999999999999965e-1) + m3 * cos(q2) * (-0.252000000000000002e-1) + 0.1000000000e1 * r2c3y * m3 * r2c3x * cos((2 * q3 + 2 * q2)) - 0.5000000000e0 * i31x * sin((2 * q3 + 2 * q2)) - 0.5000000000e0 * i31y * cos((2 * q3 + 2 * q2)) - 0.5000000000e0 * i32x * cos((2 * q3 + 2 * q2)) + 0.5000000000e0 * i32y * sin((2 * q3 + 2 * q2)) + r2c3x * m3 * cos((q3 + 2 * q2)) * (-0.359999999999999987e0) - 0.5000000000e0 * m3 * r2c3y ^ 2 * sin((2 * q3 + 2 * q2)) + 0.7000000000e-1 * r2c3x * m3 * sin((q3 + q2)) + 0.7000000000e-1 * r2c3y * m3 * cos((q3 + q2)) + r2c3y * m3 * sin((q3 + 2 * q2)) * 0.359999999999999987e0 + 0.5000000000e0 * m3 * r2c3x ^ 2 * sin((2 * q3 + 2 * q2)) - 0.1000000000e1 * r1c2y * m2 * r1c2x * cos((2 * q2))) * Dq1 + ((-0.1000000000e1 * i33x * cos((q3 + q2)) - 0.1000000000e1 * i23y * cos(q2) - 0.1000000000e1 * i23x * sin(q2) + 0.1000000000e1 * i33y * sin((q3 + q2)) + 0.1000000000e1 * cos(q2) * i22z + 0.1000000000e1 * sin(q2) * i21z + 0.1000000000e1 * cos((q3 + q2)) * i31z - 0.1000000000e1 * sin((q3 + q2)) * i32z) * Dq2 + (-0.1000000000e1 * i33x * cos((q3 + q2)) - 0.1000000000e1 * sin((q3 + q2)) * i32z + 0.1000000000e1 * i33y * sin((q3 + q2)) + 0.1000000000e1 * cos((q3 + q2)) * i31z) * Dq3);
    c22 = (r2c3y * m3 * sin(q3) * 0.719999999999999973e0 + r2c3x * m3 * cos(q3) * (-0.719999999999999973e0)) * Dq3;
    c23 = (r2c3x * m3 * cos(q3) * (-0.359999999999999987e0) + r2c3y * m3 * sin(q3) * 0.359999999999999987e0) * Dq3;
    c31 = (0.1800000000e0 * r2c3x * m3 * cos(q3) - 0.1800000000e0 * r2c3x * m3 * cos(q3 + (2 * q2)) + 0.1000000000e1 * r2c3y * m3 * r2c3x * cos(0.2e1 * q3 + (2 * q2)) - 0.5000000000e0 * m3 * r2c3y ^ 2 * sin(0.2e1 * q3 + (2 * q2)) + 0.7000000000e-1 * r2c3x * m3 * sin(q3 + q2) + 0.7000000000e-1 * r2c3y * m3 * cos(q3 + q2) + 0.1800000000e0 * r2c3y * m3 * sin(q3 + (2 * q2)) - 0.1800000000e0 * r2c3y * m3 * sin(q3) + 0.5000000000e0 * m3 * r2c3x ^ 2 * sin(0.2e1 * q3 + (2 * q2)) - 0.5000000000e0 * i31x * sin(0.2e1 * q3 + (2 * q2)) - 0.5000000000e0 * i31y - 0.5000000000e0 * i31y * cos(0.2e1 * q3 + (2 * q2)) + 0.5000000000e0 * i32x - 0.5000000000e0 * i32x * cos(0.2e1 * q3 + (2 * q2)) + 0.5000000000e0 * i32y * sin(0.2e1 * q3 + (2 * q2))) * Dq1 + ((-0.1000000000e1 * i33x * cos(q3 + q2) - 0.1000000000e1 * sin(q3 + q2) * i32z + 0.1000000000e1 * i33y * sin(q3 + q2) + 0.1000000000e1 * cos(q3 + q2) * i31z) * Dq2 + (-0.1000000000e1 * i33x * cos(q3 + q2) - 0.1000000000e1 * sin(q3 + q2) * i32z + 0.1000000000e1 * i33y * sin(q3 + q2) + 0.1000000000e1 * cos(q3 + q2) * i31z) * Dq3);
    c32 = (-0.3600000000e0 * r2c3y * m3 * sin(q3) + 0.3600000000e0 * r2c3x * m3 * cos(q3)) * Dq2;
    c33 = 0;

    %% Defining the Dynamic System
    M = [m11 m12 m13;m21 m22 m23;m31 m32 m33];
    C = [c11 c12 c13; c21 c22 c23; c31 c32 c33];
    G = [g1; g2; g3]; 
    
    
    %% Calculating DDq from the dynamic model 
    DynSys = (M^(-1))*([u1; u2; u3] - C*[Dq1;Dq2;Dq3] - G);


    %% Order reduction
    dx1 = Dq1;
    dx2 = DynSys(1);
    dx3 = Dq2;
    dx4 = DynSys(2);
    dx5 = Dq3;
    dx6 = DynSys(3);
    
    %% Output definitions
    dx = [dx1;dx2;dx3;dx4;dx5;dx6];
    block.OutputPort(1).Data = dx;