%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%           Plotting various responses for chapter 6.                 %%%
%%%         Comment/Uncomment to hide or see more plots.                %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Saving values sent to workspace in vectors
t = states.time;
tdC = qdesC.time;
tdSL = qdesSL.time;

q1 = states.signals.values(1,:);
Dq1 = states.signals.values(2,:);
q2 = states.signals.values(3,:);
Dq2 = states.signals.values(4,:);
q3 = states.signals.values(5,:);
Dq3 = states.signals.values(6,:);

q1desC = qdesC.signals.values(:,1);
q2desC = qdesC.signals.values(:,2);
q3desC = qdesC.signals.values(:,3);

q1desSL = qdesSL.signals.values(:,1);
q2desSL = qdesSL.signals.values(:,2);
q3desSL = qdesSL.signals.values(:,3);

u1 = torque.signals.values(:,1);
u2 = torque.signals.values(:,2);
u3 = torque.signals.values(:,3);

x = xyz.signals.values(:,4);
xdes = xyz.signals.values(:,1);
y = xyz.signals.values(:,5);
ydes = xyz.signals.values(:,2);
z = xyz.signals.values(:,6);
zdes = xyz.signals.values(:,3);

e1 = error.signals.values(:,1);
e2 = error.signals.values(:,2);
e3 = error.signals.values(:,3);

errorx = errorxyz.signals.values(:,1);
errory = errorxyz.signals.values(:,2);
errorz = errorxyz.signals.values(:,3);

errortot = errortotal.signals.values(:,1);
errortotTheta = errortotal.signals.values(:,2);

veloprof = splineC.signals.values(:,1);

thetafunction = thetafuncC.signals.values(:,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the response of the joint variables (fine) and desired (dashed)
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,q1,'k',t,q2,'b',t,q3,'g','LineWidth',2.5);
hold on
plot(tdC,q1desC,'--k',tdC,q2desC,'--b',tdC,q3desC,'--g','LineWidth',2.5);
hold on
plot(tdSL,q1desSL,'--k',tdSL,q2desSL,'--b',tdSL,q3desSL,'--g','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('Radians')
title('Response of q (fine) and q* (dashed)','FontSize',12)
legend('q_1','q_2','q_3','Location','NorthEast')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the response of the derivate joint variables
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,Dq1,'k',t,Dq2,'b',t,Dq3,'g','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('Radians')
title('Response of qdot','FontSize',12)
legend('dq_1','dq_2','dq_3','Location','NorthEast')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the response in xyz-coordinates vs the desired xyz-signal
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,x,'r',t,y,'b',t,z,'k','LineWidth',2.5);
hold on
plot(t,xdes,'--r',t,ydes,'--b',t,zdes,'--k','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('x,y,z [m]')
title('Trajectory in task space','FontSize',12)
legend('x(t)','y(t)','z(t)','Location','NorthEast')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the error between q and phi(theta)in radians
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(t,e1,'--r',t,e2,'--b',t,e3,'--k','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('Radians')
title('Error plot between q and q*','FontSize',12)
legend('y_1','y_2','y_3','Location','NorthEast')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the interpolation response
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(tdC,veloprof,'k','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('(d/dt) \theta')
title('Velocity profile','FontSize',12)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the obtained theta function
figure('units','pixels','outerposition',[0 0 1000 600]);
plot(tdC,thetafunction,'b','LineWidth',2.5);
grid on;
xlabel('Time [s]')
ylabel('\theta')
title('Velocity profile','FontSize',12)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %Plotting the input torques
% figure('units','pixels','outerposition',[0 0 1000 600]);
% plot(t,u1,'k',t,u2,'b',t,u3,'g','LineWidth',2.5);
% grid on;
% xlabel('Time [s]')
% ylabel('Torque [Nm]')
% title('Input torque','FontSize',12)
% legend('\tau_1','\tau_2','\tau_3','Location','NorthEast')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%