%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%           Generating various plots used in chapter 5,               %%%
%%%           based on path constrained trajectory planning.            %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;
clc;

%Defining the variable theta_t
theta=sym('theta');

%Defining phi(theta_t) from Maple Calculations
phi1 = atan2(0.2e-1 * sin(theta), 0.4710025126e0 + 0.2e-1 * cos(theta)) + 0.4243712498e-1;
phi2 = 0.1570796327e1 - 0.1e1 * asin(0.445e0 * sqrt(0.1e1 - 0.1e1 * (-0.1014110487e1 + 0.3121098627e1 * (0.4010025126e0 + 0.2e-1 * cos(theta)) ^ 2) ^ 2) * (0.2704e-2 + (0.4010025126e0 + 0.2e-1 * cos(theta)) ^ 2) ^ (-0.1e1 / 0.2e1)) + atan(0.52e-1 / (0.4010025126e0 + 0.2e-1 * cos(theta)));
phi3 = -0.1570796327e1 + acos(-0.1014110487e1 + 0.3121098627e1 * (0.4010025126e0 + 0.2e-1 * cos(theta)) ^ 2);

%Differentiating phi(theta_t) with respect to theta_t
dphi1 = diff(phi1,theta);
dphi2 = diff(phi2,theta);
dphi3 = diff(phi3,theta);

%Assigning the absolute values of phi'(theta_t)
absdphi1 = abs(dphi1);
absdphi2 = abs(dphi2);
absdphi3 = abs(dphi3);

%Generating boundary curves
s1 = (3.4907/absdphi1);
s2 = (3.4907/absdphi2);
s3 = (4.5379/absdphi3);

%PLOT 1: q(theta_t) based on Inverse Kinematic Calculations
figure('units','pixels','outerposition',[0 0 1000 600]);
set(ezplot(phi1), 'Color', 'black','LineWidth',2)
hold on;
set(ezplot(phi2), 'Color', 'green','LineWidth',2)
hold on;
set(ezplot(phi3), 'Color', 'blue','LineWidth',2)
axis([-pi pi -1.5 1.5])
grid on;
title('q(theta_1)','FontSize',12)
h=legend('q_1','q_2','q_3','Location','NorthEast');
set(h,'FontSize',12)
xlabel('\theta_t, [rad]','FontSize',12)
ylabel('q(\theta_t), [rad]','FontSize',12)


%PLOT 2: Boundary Curves
figure('units','pixels','outerposition',[0 0 1000 600]);
set(ezplot(s1), 'Color', 'black','LineWidth',2)
hold on;
set(ezplot(s2), 'Color', 'green','LineWidth',2)
hold on;
set(ezplot(s3), 'Color', 'blue','LineWidth',2)
axis([-pi pi 0 160])
grid on;
title('Boundry curves','FontSize',12)
h2=legend('b_1','b_2','b_3','Location','NorthEast');
set(h2,'FontSize',12)
xlabel('\theta_1, [rad]','FontSize',12)
ylabel('d\theta_1/dt, [rad/s]','FontSize',12)